<?php
 /**
  * @version   $Id: Unsupported.php 48519 2012-02-03 23:18:52Z btowles $
  * @author    RocketTheme http://www.rockettheme.com
  * @copyright Copyright (C) 2007 - ${copyright_year} RocketTheme, LLC
  * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
  */
 
class RokCommon_Header_Unsupported implements RokCommon_Header_Interface
{
    /**
     *
     */
    public function __construct()
    {
    }
    /**
     * @param $file
     */
    public function addScript($file)
    {
    }

    /**
     * @param $text
     */
    public function addInlineScript($text)
    {
    }

    /**
     * @param $file
     */
    public function addStyle($file)
    {
    }

    /**
     * @param $text
     */
    public function addInlineStyle($text)
    {
    }

}
